@@ -17,8 +17,8 @@ import termcolor
 import random
 import py_compile
 from pathlib import Path
-from clouderizer.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set
-from clouderizer.utils import check_aws_cli_exists, check_sam_cli_exists
+from clouderizer_beta.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set
+from clouderizer_beta.utils import check_aws_cli_exists, check_sam_cli_exists
 from yaml import load, dump
 # from clouderizer_beta.utils import prepend_line
 try:
@@ -27,7 +27,7 @@ except ImportError:
     from yaml import Loader, Dumper
 
 # BASE_URL="https://showcase.clouderizer.com"
-BASE_URL="https://showcase.clouderizer.com"
+BASE_URL="https://betaconsole.clouderizer.com"
 SYNC_URL="https://serverless.clouderizer.com/function/"
 
 upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
@@ -479,7 +479,7 @@ def create_serving_project(filename,companyid,auth_token,projectName=None,inputA
 		return create_serving_project(filename,companyid,auth_token,retry)
 
 
-def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess=None,postprocess=None,predict=None,inputAttrs=[],outputAttrs=[],retry=0,is_lambda_deploy="false"):
+def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess=None,postprocess=None,predict=None,retry=0,is_lambda_deploy="false"):
 	# print("Inside")
 	company=servingproject["company"]
 	auth_headers={"Authorization": "Bearer "+auth_token}
@@ -530,8 +530,6 @@ def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPac
 		"predictCode": predictCode,
 		"predictCodePath": predictS3Path,
 		"imagetype" : image_type,
-		"inputAttr" : inputAttrs,
-		"outputAttr": outputAttrs,
 		"lambda": is_lambda_deploy
 	}
 
@@ -956,7 +954,7 @@ class Clouderizer(object):
 
 		published_serving_projects=requests.post(BASE_URL+'/api/servingproject/getprojects',data={"company":creds["cid"]})
 
-		print(published_serving_projects.text)
+		# print(published_serving_projects.text)
 		published_serving_projects=parse_json(published_serving_projects.text)
 		clear_local_project_list()
 		# except Exception as e:
@@ -1160,6 +1158,7 @@ class Clouderizer(object):
 
 		# try:
 		customer_dets = parse_json(customer_dets.text)
+		# print(customer_dets)
 		# except Exception as e:
 		#   print("Could not fetch your details")
 		#   return
@@ -1608,7 +1607,7 @@ class Clouderizer(object):
 				uploadmodel_resp=upload_to_showcase(s3Path,notebook_path,servingproject["company"],auth_token)
 				if uploadmodel_resp=="Success":
 					try:
-						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"true","regular",subtype,image,inputAttrs=inputAttrs,outputAttrs=outputAttrs)
+						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"true","regular",subtype,image)
 					except Exception as e:
 						print(e)
 						print("Some exception occurred while preparing your notebook, please try again!")
@@ -2114,7 +2113,7 @@ class Clouderizer(object):
 						deployment_model_type="automl"
 						if subtype in ["python","onnx","pythonscore"]:
 							deployment_model_type="regular"
-						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"false",deployment_model_type,subtype,"standard",preprocess=preprocess_path,postprocess=postprocess_path,predict=predict_path,inputAttrs=inputAttrs,outputAttrs=outputAttrs)
+						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"false",deployment_model_type,subtype,"standard",preprocess=preprocess_path,postprocess=postprocess_path,predict=predict_path,is_lambda_deploy="true")
 					except Exception as e:
 						print(e)
 						print("Some exception occurred while preparing your model, please try again!")						
